@@ -6,7 +6,7 @@ describe Hashie::Extensions::IndifferentAccess do
     include Hashie::Extensions::IndifferentAccess
 
     class << self
-      alias_method :build, :new
+      alias build new
     end
   end
 
@@ -14,7 +14,7 @@ describe Hashie::Extensions::IndifferentAccess do
     include Hashie::Extensions::IndifferentAccess
 
     class << self
-      alias_method :build, :[]
+      alias build []
     end
   end
 
@@ -22,7 +22,7 @@ describe Hashie::Extensions::IndifferentAccess do
     include Hashie::Extensions::IndifferentAccess
 
     class << self
-      alias_method :build, :try_convert
+      alias build try_convert
     end
   end
 
@@ -44,11 +44,24 @@ describe Hashie::Extensions::IndifferentAccess do
         include Hashie::Extensions::IndifferentAccess
       end.new
 
-      merged_hash = indifferent_hash.merge(:cat => 'meow')
+      merged_hash = indifferent_hash.merge(cat: 'meow')
 
       expect(merged_hash[:cat]).to eq('meow')
       expect(merged_hash['cat']).to eq('meow')
     end
+
+    it 'injects the resulting new Hash with IndifferentAccess' do
+      hash = IndifferentHashWithMergeInitializer.new(
+        :cat => 'meow',
+        'dog' => { name: 'Mango', sound: 'woof' }
+      )
+
+      dog = hash[:dog]
+      merged = dog.merge(foo: 'bar')
+
+      expect(merged[:foo]).to eq('bar')
+      expect(merged['foo']).to eq('bar')
+    end
   end
 
   describe '#merge!' do
@@ -57,13 +70,43 @@ describe Hashie::Extensions::IndifferentAccess do
         include Hashie::Extensions::IndifferentAccess
       end.new
 
-      indifferent_hash.merge!(:cat => 'meow')
+      indifferent_hash[:cat] = 'meow'
 
       expect(indifferent_hash[:cat]).to eq('meow')
       expect(indifferent_hash['cat']).to eq('meow')
     end
   end
 
+  describe '#to_hash' do
+    let(:indifferent_hash) { Class.new(::Hash) { include Hashie::Extensions::IndifferentAccess } }
+
+    it 'returns a normal hash without indifference' do
+      indifferent = indifferent_hash.new
+      indifferent['cat'] = 'meow'
+
+      subject = indifferent.to_hash
+
+      expect(subject['cat']).to eq 'meow'
+      expect(subject[:cat]).to be_nil
+    end
+
+    it 'maintains the #default_proc when set' do
+      indifferent = indifferent_hash.new { |_hash, key| "Nothing here: #{key}" }
+
+      subject = indifferent.to_hash
+
+      expect(subject['babble']).to eq 'Nothing here: babble'
+    end
+
+    it 'maintains the #default when set' do
+      indifferent = indifferent_hash.new(0)
+
+      subject = indifferent.to_hash
+
+      expect(subject['babble']).to eq 0
+    end
+  end
+
   describe 'when included in dash' do
     let(:params) { { foo: 'bar' } }
     subject { IndifferentHashWithDash.new(params) }
@@ -73,6 +116,45 @@ describe Hashie::Extensions::IndifferentAccess do
     end
   end
 
+  describe 'when overriding indifferent methods' do
+    let(:indifferent_hash) do
+      Class.new(::Hash) do
+        include Hashie::Extensions::IndifferentAccess
+
+        ALIASES = { cat: :grumpy }.freeze
+
+        # Override writer to maintain alias of the given key
+        def indifferent_writer(key, value)
+          indifferent_value = indifferent_value(value)
+
+          regular_writer convert_key(key),          indifferent_value
+          regular_writer convert_key(ALIASES[key]), indifferent_value
+        end
+        alias_method :[]=, :indifferent_writer
+      end.new
+    end
+
+    it '#indifferent_writer' do
+      indifferent_hash[:cat] = 'meow'
+
+      expect(indifferent_hash[:cat]).to eq('meow')
+      expect(indifferent_hash['cat']).to eq('meow')
+
+      expect(indifferent_hash[:grumpy]).to eq('meow')
+      expect(indifferent_hash['grumpy']).to eq('meow')
+    end
+
+    it '#merge' do
+      merged_hash = indifferent_hash.merge(cat: 'meow')
+
+      expect(merged_hash[:cat]).to eq('meow')
+      expect(merged_hash['cat']).to eq('meow')
+
+      expect(merged_hash[:grumpy]).to eq('meow')
+      expect(merged_hash['grumpy']).to eq('meow')
+    end
+  end
+
   describe 'when translating properties and ignoring undeclared' do
     let(:value) { 'baz' }
 
@@ -113,7 +195,7 @@ describe Hashie::Extensions::IndifferentAccess do
     describe '#values_at' do
       it 'indifferently finds values' do
         h = subject.build(:foo => 'bar', 'baz' => 'qux')
-        expect(h.values_at('foo', :baz)).to eq %w(bar qux)
+        expect(h.values_at('foo', :baz)).to eq %w[bar qux]
       end
 
       it 'returns the same instance of the hash that was set' do
@@ -195,7 +277,7 @@ describe Hashie::Extensions::IndifferentAccess do
         expect(h).to be_key('foo')
       end
 
-      %w(include? member? has_key?).each do |key_alias|
+      %w[include? member? has_key?].each do |key_alias|
         it "is aliased as #{key_alias}" do
           expect(h.send(key_alias.to_sym, :foo)).to be(true)
           expect(h.send(key_alias.to_sym, 'foo')).to be(true)
@@ -263,6 +345,30 @@ describe Hashie::Extensions::IndifferentAccess do
         end
       end
     end
+
+    with_minimum_ruby('2.5.0') do
+      describe '#slice' do
+        let(:h) { subject.build(foo: 'bar', baz: 'qux') }
+
+        it 'indifferently slices the hash' do
+          sliced_h = { 'foo' => 'bar' }
+          expect(h.slice('foo')).to eq sliced_h
+          expect(h.slice(:foo)).to eq sliced_h
+        end
+      end
+    end
+
+    with_minimum_ruby('3.0.0') do
+      describe '#except' do
+        let(:h) { subject.build(foo: 'bar', baz: 'qux') }
+
+        it 'indifferently excepts keys from the hash' do
+          sliced_h = { 'baz' => 'qux' }
+          expect(h.except('foo')).to eq sliced_h
+          expect(h.except(:foo)).to eq sliced_h
+        end
+      end
+    end
   end
 
   describe 'with merge initializer' do
