@@ -75,7 +75,7 @@ describe Hashie::Mash do
   # Added due to downstream gems assuming indifferent access to be true for Mash
   # When this is not, bump major version so that downstream gems can target
   # correct version and fix accordingly.
-  # See https://github.com/intridea/hashie/pull/197
+  # See https://github.com/hashie/hashie/pull/197
   it 'maintains indifferent access when nested' do
     subject[:a] = { b: 'c' }
     expect(subject[:a][:b]).to eq 'c'
@@ -147,21 +147,44 @@ describe Hashie::Mash do
       mash[:test_key] = 'Test value'
 
       expect { mash[:test_key] = 'A new value' }.not_to raise_error
-      expect(logger_output).to be_blank
+      expect(logger_output).to be_empty
     end
 
     it 'does not write to the logger when warnings are disabled' do
       mash_class = Class.new(Hashie::Mash) do
         disable_warnings
       end
-
       mash_class.new('trust' => { 'two' => 2 })
 
-      expect(logger_output).to be_blank
+      expect(logger_output).to be_empty
+    end
+
+    it 'does not write to the logger when setting most affixed keys' do
+      underbang = Hashie::Mash.new('foo_' => 'foo')
+      bang = Hashie::Mash.new('foo!' => 'foo')
+      query = Hashie::Mash.new('foo?' => 'foo')
+
+      expect(logger_output).to be_empty
+      expect(underbang.foo_).to eq 'foo'
+      expect(bang.foo!).to eq 'foo'
+      expect(query.foo?).to eq 'foo'
+    end
+
+    it 'warns when setting a key that looks like a setter' do
+      setter = Hashie::Mash.new('foo=' => 'foo')
+
+      expect(logger_output).to match 'Hashie::Mash#foo='
+      expect('setter.foo=').not_to parse_as_valid_ruby
+
+      setter.foo = 'bar'
+
+      expect(setter.to_h).to eq 'foo=' => 'foo'
     end
 
     it 'cannot disable logging on the base Mash' do
-      expect { Hashie::Mash.disable_warnings }.to raise_error(Hashie::Mash::CannotDisableMashWarnings)
+      expected_error = Hashie::Extensions::KeyConflictWarning::CannotDisableMashWarnings
+
+      expect { Hashie::Mash.disable_warnings }.to raise_error(expected_error)
     end
 
     it 'carries over the disable for warnings on grandchild classes' do
@@ -172,7 +195,79 @@ describe Hashie::Mash do
 
       grandchild_class.new('trust' => { 'two' => 2 })
 
-      expect(logger_output).to be_blank
+      expect(logger_output).to be_empty
+    end
+
+    it 'writes to logger when a key is overridden that is not ignored' do
+      mash_class = Class.new(Hashie::Mash) do
+        disable_warnings :merge
+      end
+
+      mash_class.new('address' => { 'zip' => '90210' })
+      expect(logger_output).not_to be_empty
+    end
+
+    it 'does not write to logger when a key is overridden that is ignored' do
+      mash_class = Class.new(Hashie::Mash) do
+        disable_warnings :zip
+      end
+
+      mash_class.new('address' => { 'zip' => '90210' })
+      expect(logger_output).to be_empty
+    end
+
+    it 'carries over the ignored warnings list for warnings on grandchild classes' do
+      child_class = Class.new(Hashie::Mash) do
+        disable_warnings :zip, :merge
+      end
+      grandchild_class = Class.new(child_class)
+
+      grandchild_class.new('address' => { 'zip' => '90210' }, 'merge' => true)
+
+      expect(grandchild_class.disabled_warnings).to eq(%i[zip merge])
+      expect(logger_output).to be_empty
+    end
+
+    context 'multiple disable_warnings calls' do
+      context 'calling disable_warnings multiple times with parameters' do
+        it 'appends each new parameter to the ignore list' do
+          child_class = Class.new(Hashie::Mash) do
+            disable_warnings :zip
+            disable_warnings :merge
+            disable_warnings :cycle
+          end
+
+          expect(child_class.disabled_warnings).to eq(%i[zip merge cycle])
+        end
+      end
+
+      context 'calling disable_warnings without keys after calling with keys' do
+        it 'uses the last call to determine the ignore list' do
+          child_class = Class.new(Hashie::Mash) do
+            disable_warnings :zip
+            disable_warnings
+          end
+
+          child_class.new('address' => { 'zip' => '90210' }, 'merge' => true, 'cycle' => 'bi')
+
+          expect(child_class.disabled_warnings).to eq([])
+          expect(logger_output).to be_empty
+        end
+      end
+
+      context 'calling disable_parameters with keys after calling without keys' do
+        it 'only ignores logging for ignored methods' do
+          child_class = Class.new(Hashie::Mash) do
+            disable_warnings
+            disable_warnings :zip
+          end
+
+          child_class.new('address' => { 'zip' => '90210' }, 'merge' => true)
+
+          expect(logger_output).to match(/#{child_class}#merge/)
+          expect(logger_output).not_to match(/#{child_class}#zip/)
+        end
+      end
     end
   end
 
@@ -184,7 +279,8 @@ describe Hashie::Mash do
         details: {
           email: 'michael@asf.com',
           address: 'Nowhere road'
-        })
+        }
+      )
     end
 
     describe '#deep_update' do
@@ -228,15 +324,29 @@ describe Hashie::Mash do
 
       # http://www.ruby-doc.org/core-1.9.3/Hash.html#method-i-update
       it 'accepts a block' do
-        duped = subject.merge(details: { address: 'Pasadena CA' }) { |_, oldv, newv| [oldv, newv].join(', ') }
+        duped = subject.merge(details: { address: 'Pasadena CA' }) do |_, oldv, newv|
+          [oldv, newv].join(', ')
+        end
+
         expect(duped.details.address).to eq 'Nowhere road, Pasadena CA'
       end
 
       it 'copies values for non-duplicate keys when a block is supplied' do
-        duped = subject.merge(details: { address: 'Pasadena CA', state: 'West Thoughtleby' }) { |_, oldv, _| oldv }
+        m_hash = { details: { address: 'Pasadena CA', state: 'West Thoughtleby' } }
+        duped = subject.merge(m_hash) { |_, oldv, _| oldv }
+
         expect(duped.details.address).to eq 'Nowhere road'
         expect(duped.details.state).to eq 'West Thoughtleby'
       end
+
+      it 'does not raise an exception when default_proc raises an error' do
+        hash = described_class.new(a: 1) { |_k, _v| raise('Should not be raise I') }
+        other_has = described_class.new(a: 2, b: 2) { |_k, _v| raise('Should not be raise II') }
+        expected_hash = described_class.new(a: 2, b: 2)
+
+        res = hash.merge(other_has)
+        expect(res).to eq(expected_hash)
+      end
     end
 
     describe 'shallow update' do
@@ -284,7 +394,7 @@ describe Hashie::Mash do
       end
 
       it 'leaves only specified keys' do
-        expect(subject.keys.sort).to eq %w(details middle_name)
+        expect(subject.keys.sort).to eq %w[details middle_name]
         expect(subject.first_name?).to be_falsy
         expect(subject).not_to respond_to(:first_name)
         expect(subject.last_name?).to be_falsy
@@ -386,28 +496,28 @@ describe Hashie::Mash do
     end
 
     it 'responds to a set key with a suffix' do
-      %w(= ? ! _).each do |suffix|
+      %w[= ? ! _].each do |suffix|
         expect(subject).to be_respond_to(:"abc#{suffix}")
       end
     end
 
     it 'is able to access the suffixed key as a method' do
-      %w(= ? ! _).each do |suffix|
+      %w[= ? ! _].each do |suffix|
         expect(subject.method(:"abc#{suffix}")).to_not be_nil
       end
     end
 
     it 'responds to an unknown key with a suffix' do
-      %w(= ? ! _).each do |suffix|
+      %w[= ? ! _].each do |suffix|
         expect(subject).to be_respond_to(:"xyz#{suffix}")
       end
     end
 
     it 'is able to access an unknown suffixed key as a method' do
       # See https://github.com/intridea/hashie/pull/285 for more information
-      pending_for(engine: 'ruby', versions: %w(2.2.0 2.2.1 2.2.2))
+      pending_for(engine: 'ruby', versions: %w[2.2.0 2.2.1 2.2.2])
 
-      %w(= ? ! _).each do |suffix|
+      %w[= ? ! _].each do |suffix|
         expect(subject.method(:"xyz#{suffix}")).to_not be_nil
       end
     end
@@ -457,6 +567,13 @@ describe Hashie::Mash do
       expect(initial.test?).to be_truthy
     end
 
+    it 'allows propagation of a default block' do
+      h = Hashie::Mash.new { |mash, key| mash[key] = mash.class.new(&mash.default_proc) }
+      expect { h[:x][:y][:z] = :xyz }.not_to raise_error
+      expect(h.x.y.z).to eq(:xyz)
+      expect(h[:x][:y][:z]).to eq(:xyz)
+    end
+
     it 'allows assignment of an empty array in a default block' do
       initial = Hashie::Mash.new { |h, k| h[k] = [] }
       initial.hello << 100
@@ -496,6 +613,18 @@ describe Hashie::Mash do
       expect(converted.to_hash['a'].first.is_a?(Hash)).to be_truthy
       expect(converted.to_hash['a'].first['c'].first.is_a?(Hashie::Mash)).to be_falsy
     end
+
+    it 'only stringifies keys which can be converted to symbols' do
+      initial_hash = { 1 => 'a', ['b'] => 2, 'c' => 3, d: 4 }
+      converted = Hashie::Mash.new(initial_hash)
+      expect(converted).to eq(1 => 'a', ['b'] => 2, 'c' => 3, 'd' => 4)
+    end
+
+    it 'preserves keys which cannot be converted to symbols' do
+      initial_hash = { 1 => 'a', '1' => 'b', :'1' => 'c' }
+      converted = Hashie::Mash.new(initial_hash)
+      expect(converted).to eq(1 => 'a', '1' => 'c')
+    end
   end
 
   describe '#fetch' do
@@ -553,7 +682,7 @@ describe Hashie::Mash do
     end
 
     it 'includes all keys' do
-      expect(mash.to_hash.keys).to eql(%w(outer testing))
+      expect(mash.to_hash.keys).to eql(%w[outer testing])
     end
 
     it 'converts keys to symbols when symbolize_keys option is true' do
@@ -625,7 +754,7 @@ describe Hashie::Mash do
     context 'if the file exists' do
       before do
         expect(File).to receive(:file?).with(path).and_return(true)
-        expect(parser).to receive(:perform).with(path).and_return(config)
+        expect(parser).to receive(:perform).with(path, {}).and_return(config)
       end
 
       it { is_expected.to be_a(Hashie::Mash) }
@@ -657,7 +786,7 @@ describe Hashie::Mash do
 
       before do
         expect(File).to receive(:file?).with(path).and_return(true)
-        expect(parser).to receive(:perform).with(path).and_return(config)
+        expect(parser).to receive(:perform).with(path, {}).and_return(config)
       end
 
       it 'return a Mash from a file' do
@@ -673,8 +802,8 @@ describe Hashie::Mash do
       before do
         expect(File).to receive(:file?).with(path).and_return(true)
         expect(File).to receive(:file?).with("#{path}+1").and_return(true)
-        expect(parser).to receive(:perform).once.with(path).and_return(config)
-        expect(parser).to receive(:perform).once.with("#{path}+1").and_return(config)
+        expect(parser).to receive(:perform).once.with(path, {}).and_return(config)
+        expect(parser).to receive(:perform).once.with("#{path}+1", {}).and_return(config)
       end
 
       it 'cache the loaded yml file', :test_cache do
@@ -686,6 +815,50 @@ describe Hashie::Mash do
         expect(subject.object_id).to eq subject.object_id
       end
     end
+
+    context 'when the file has aliases in it' do
+      it 'can use the aliases and does not raise an error' do
+        mash = Hashie::Mash.load('spec/fixtures/yaml_with_aliases.yml')
+        expect(mash.company_a.accounts.admin.password).to eq('secret')
+      end
+      it 'can override the value of aliases' do
+        expect do
+          Hashie::Mash.load('spec/fixtures/yaml_with_aliases.yml', aliases: false)
+        end.to raise_error Psych::BadAlias, /base_accounts/
+      end
+    end
+
+    context 'when the file has symbols' do
+      it 'can override the value of permitted_classes' do
+        mash = Hashie::Mash.load('spec/fixtures/yaml_with_symbols.yml', permitted_classes: [Symbol])
+        expect(mash.user_icon.width).to eq(200)
+      end
+      it 'uses defaults for permitted_classes' do
+        expect do
+          Hashie::Mash.load('spec/fixtures/yaml_with_symbols.yml')
+        end.to raise_error Psych::DisallowedClass, /Symbol/
+      end
+      it 'can override the value of permitted_symbols' do
+        mash = Hashie::Mash.load('spec/fixtures/yaml_with_symbols.yml',
+                                 permitted_classes: [Symbol],
+                                 permitted_symbols: %i[
+                                   user_icon
+                                   width
+                                   height
+                                 ])
+        expect(mash.user_icon.width).to eq(200)
+      end
+      it 'raises an error on insufficient permitted_symbols' do
+        expect do
+          Hashie::Mash.load('spec/fixtures/yaml_with_symbols.yml',
+                            permitted_classes: [Symbol],
+                            permitted_symbols: %i[
+                              user_icon
+                              width
+                            ])
+        end.to raise_error Psych::DisallowedClass, /Symbol/
+      end
+    end
   end
 
   describe '#to_module(mash_method_name)' do
@@ -709,18 +882,6 @@ describe Hashie::Mash do
     end
   end
 
-  describe '#extractable_options?' do
-    require 'active_support'
-
-    subject { described_class.new(name: 'foo') }
-    let(:args) { [101, 'bar', subject] }
-
-    it 'can be extracted from an array' do
-      expect(args.extract_options!).to eq subject
-      expect(args).to eq [101, 'bar']
-    end
-  end
-
   describe '#reverse_merge' do
     subject { described_class.new(a: 1, b: 2) }
 
@@ -743,21 +904,210 @@ describe Hashie::Mash do
     end
   end
 
+  describe '#invert' do
+    subject(:mash) { described_class.new(a: 'apple', b: 4) }
+
+    it 'returns a Hashie::Mash' do
+      expect(mash.invert).to be_kind_of(described_class)
+    end
+
+    it 'returns a mash with the keys and values inverted' do
+      expect(mash.invert).to eq('apple' => 'a', 4 => 'b')
+    end
+
+    context 'when using with subclass' do
+      let(:subclass) { Class.new(Hashie::Mash) }
+      subject(:sub_mash) { subclass.new(a: 1, b: nil) }
+
+      it 'creates an instance of subclass' do
+        expect(sub_mash.invert).to be_kind_of(subclass)
+      end
+    end
+  end
+
+  describe '#reject' do
+    subject(:mash) { described_class.new(a: 1, b: nil) }
+
+    it 'returns a Hashie::Mash' do
+      expect(mash.reject { |_k, v| v.nil? }).to be_kind_of(described_class)
+    end
+
+    it 'rejects keys for which the block returns true' do
+      expect(mash.reject { |_k, v| v.nil? }).to eq('a' => 1)
+    end
+
+    context 'when using with subclass' do
+      let(:subclass) { Class.new(Hashie::Mash) }
+      subject(:sub_mash) { subclass.new(a: 1, b: nil) }
+
+      it 'creates an instance of subclass' do
+        expect(sub_mash.reject { |_k, v| v.nil? }).to be_kind_of(subclass)
+      end
+    end
+  end
+
+  describe '#select' do
+    subject(:mash) { described_class.new(a: 'apple', b: 4) }
+
+    it 'returns a Hashie::Mash' do
+      expect(mash.select { |_k, v| v.is_a? String }).to be_kind_of(described_class)
+    end
+
+    it 'selects keys for which the block returns true' do
+      expect(mash.select { |_k, v| v.is_a? String }).to eq('a' => 'apple')
+    end
+
+    context 'when using with subclass' do
+      let(:subclass) { Class.new(Hashie::Mash) }
+      subject(:sub_mash) { subclass.new(a: 1, b: nil) }
+
+      it 'creates an instance of subclass' do
+        expect(sub_mash.select { |_k, v| v.is_a? String }).to be_kind_of(subclass)
+      end
+    end
+  end
+
+  describe '.quiet' do
+    it 'returns a subclass of the calling class' do
+      expect(Hashie::Mash.quiet.new).to be_a(Hashie::Mash)
+    end
+
+    it 'memoizes and returns classes' do
+      call_one = Hashie::Mash.quiet
+      call_two = Hashie::Mash.quiet
+      expect(Hashie::Mash.instance_variable_get('@memoized_classes').count).to eq(1)
+      expect(call_one).to eq(call_two)
+    end
+  end
+
   with_minimum_ruby('2.3.0') do
     describe '#dig' do
       subject { described_class.new(a: { b: 1 }) }
+
       it 'accepts both string and symbol as key' do
         expect(subject.dig(:a, :b)).to eq(1)
         expect(subject.dig('a', 'b')).to eq(1)
       end
 
-      context 'with numeric key' do
-        subject { described_class.new('1' => { b: 1 }) }
-        it 'accepts a numeric value as key' do
-          expect(subject.dig(1, :b)).to eq(1)
-          expect(subject.dig('1', :b)).to eq(1)
+      context 'when the Mash wraps a Hashie::Array' do
+        it 'handles digging into an array' do
+          mash = described_class.new(alphabet: { first_three: Hashie::Array['a', 'b', 'c'] })
+
+          expect(mash.dig(:alphabet, :first_three, 0)).to eq 'a'
         end
       end
     end
   end
+
+  with_minimum_ruby('2.4.0') do
+    describe '#transform_values' do
+      subject(:mash) { described_class.new(a: 1) }
+
+      it 'returns a Hashie::Mash' do
+        expect(mash.transform_values(&:to_s)).to be_kind_of(described_class)
+      end
+
+      it 'transforms the value' do
+        expect(mash.transform_values(&:to_s).a).to eql('1')
+      end
+
+      context 'when using with subclass' do
+        let(:subclass) { Class.new(Hashie::Mash) }
+        subject(:sub_mash) { subclass.new(a: 1).transform_values { |a| a + 2 } }
+
+        it 'creates an instance of subclass' do
+          expect(sub_mash).to be_kind_of(subclass)
+        end
+      end
+    end
+
+    describe '#compact' do
+      subject(:mash) { described_class.new(a: 1, b: nil) }
+
+      it 'returns a Hashie::Mash' do
+        expect(mash.compact).to be_kind_of(described_class)
+      end
+
+      it 'removes keys with nil values' do
+        expect(mash.compact).to eq('a' => 1)
+      end
+
+      context 'when using with subclass' do
+        let(:subclass) { Class.new(Hashie::Mash) }
+        subject(:sub_mash) { subclass.new(a: 1, b: nil) }
+
+        it 'creates an instance of subclass' do
+          expect(sub_mash.compact).to be_kind_of(subclass)
+        end
+      end
+    end
+  end
+
+  with_minimum_ruby('2.5.0') do
+    describe '#slice' do
+      subject(:mash) { described_class.new(a: 1, b: 2) }
+
+      it 'returns a Hashie::Mash' do
+        expect(mash.slice(:a)).to be_kind_of(described_class)
+      end
+
+      it 'returns a Mash with only the keys passed' do
+        expect(mash.slice(:a).to_hash).to eq('a' => 1)
+      end
+
+      context 'when using with subclass' do
+        let(:subclass) { Class.new(Hashie::Mash) }
+        subject(:sub_mash) { subclass.new(a: 1, b: 2) }
+
+        it 'creates an instance of subclass' do
+          expect(sub_mash.slice(:a)).to be_kind_of(subclass)
+        end
+      end
+    end
+
+    describe '#transform_keys' do
+      subject(:mash) { described_class.new(a: 1, b: 2) }
+
+      it 'returns a Hashie::Mash' do
+        expect(mash.transform_keys { |k| k + k }).to be_kind_of(described_class)
+      end
+
+      it 'returns a Mash with transformed keys' do
+        expect(mash.transform_keys { |k| k + k }).to eq('aa' => 1, 'bb' => 2)
+      end
+
+      context 'when using with subclass' do
+        let(:subclass) { Class.new(Hashie::Mash) }
+        subject(:sub_mash) { subclass.new(a: 1, b: 2) }
+
+        it 'creates an instance of subclass' do
+          expect(sub_mash.transform_keys { |k| k + k }).to be_kind_of(subclass)
+        end
+      end
+    end
+  end
+
+  with_minimum_ruby('2.6.0') do
+    context 'ruby 2.6 merging' do
+      subject(:mash) { Hashie::Mash.new(model: 'Honda') }
+      it 'merges multiple hashes and mashes passeed to #merge' do
+        first_hash = { model: 'Ford' }
+        second_hash = { model: 'DeLorean' }
+        expect(mash.merge(first_hash, second_hash)).to eq('model' => 'DeLorean')
+      end
+    end
+  end
+
+  with_minimum_ruby('3.0.0') do
+    context '#except' do
+      subject(:mash) { described_class.new(a: 'A', b: 'B') }
+      it 'return a Hashie::Mash' do
+        expect(mash.except(:b)).to be_kind_of(described_class)
+      end
+
+      it 'excludes keys' do
+        expect(mash.except(:b)).to eq('a' => 'A')
+      end
+    end
+  end
 end
