@@ -153,7 +153,24 @@ describe Hashie::Trash do
     end
 
     it 'maintains translations hash mapping from the original to the translated name' do
-      expect(SomeDataModel.translations).to eq(config: [:value_a, :value_b])
+      expect(SomeDataModel.translations).to eq(config: %i[value_a value_b])
+    end
+  end
+
+  describe 'translating multiple properties from the same source hash key' do
+    class AnotherDataModel < Hashie::Trash
+      property :first_name,                          transform_with: ->(n) { n.upcase }
+      property :first_name_short, from: :first_name, transform_with: ->(n) { n[0, 3] }
+    end
+
+    subject { AnotherDataModel.new(first_name: 'Cathy') }
+
+    it 'translates the first key with the given lambda' do
+      expect(subject.first_name).to eq('CATHY')
+    end
+
+    it 'translates the second key with the given lambda and the initial value of the first key' do
+      expect(subject.first_name_short).to eq('Cat')
     end
   end
 
@@ -188,7 +205,9 @@ describe Hashie::Trash do
     end
 
     it 'transforms the value when given in constructor' do
-      expect(TrashLambdaTestWithProperties.new(first_name: 'Michael').first_name).to eq 'Michael'.reverse
+      expect(
+        TrashLambdaTestWithProperties.new(first_name: 'Michael').first_name
+      ).to eq 'Michael'.reverse
     end
 
     context 'when :from option is given' do
@@ -265,4 +284,68 @@ describe Hashie::Trash do
       expect(subject.first_name).to eq('Frodo')
     end
   end
+
+  context 'when copying properties from other properties' do
+    it 'retains the original and also sets the copy' do
+      simple = Class.new(Hashie::Trash) do
+        property :id
+        property :copy_of_id, from: :id
+      end
+
+      subject = simple.new(id: 1)
+
+      expect(subject.id).to eq(1)
+      expect(subject.copy_of_id).to eq(1)
+    end
+
+    it 'grabs the default for the original if it is not set' do
+      with_default = Class.new(Hashie::Trash) do
+        property :id, default: 0
+        property :copy_of_id, from: :id
+      end
+
+      subject = with_default.new
+
+      expect(subject.id).to eq(0)
+      expect(subject.copy_of_id).to eq(0)
+    end
+
+    it 'can be a required value' do
+      with_required = Class.new(Hashie::Trash) do
+        property :id
+        property :copy_of_id, from: :id, required: true, message: 'must be set'
+      end
+
+      expect { with_required.new }.to raise_error(
+        ArgumentError, "The property 'copy_of_id' must be set"
+      )
+    end
+
+    it 'does not set properties that do not exist' do
+      from_non_property = Class.new(Hashie::Trash) do
+        property :copy_of_value, from: :value
+      end
+
+      subject = from_non_property.new(value: 0)
+
+      expect(subject).not_to respond_to(:value)
+      expect { subject[:value] }.to raise_error(
+        NoMethodError, "The property 'value' is not defined for ."
+      )
+      expect(subject.to_h[:value]).to eq(nil)
+      expect(subject.copy_of_value).to eq(0)
+    end
+
+    it 'is not order-dependent in definition' do
+      simple = Class.new(Hashie::Trash) do
+        property :copy_of_id, from: :id
+        property :id
+      end
+
+      subject = simple.new(id: 1)
+
+      expect(subject.id).to eq(1)
+      expect(subject.copy_of_id).to eq(1)
+    end
+  end
 end
